@@ -192,4 +192,20 @@ pub trait DrawingBackend: Sized {
             Err(font_error) => Err(DrawingErrorKind::FontError(font_error)),
         }
     }
+
+    /// Estimate the size of the text if rendered on this backend.
+    /// This is important because some of the backend may not have font ability.
+    /// Thus this allows those backend reports proper value rather than ask the
+    /// font rasterizer for that.
+    ///
+    /// - `text`: The text to estimate
+    /// - `font`: The font to estimate
+    /// - *Returns* The estimated text size
+    fn estimate_text_size<'a>(
+        &self,
+        text: &str,
+        font: &FontDesc<'a>,
+    ) -> Result<(u32, u32), DrawingErrorKind<Self::ErrorType>> {
+        Ok(font.box_size(text).map_err(DrawingErrorKind::FontError)?)
+    }
 }
