@@ -8,7 +8,7 @@
 <a href="https://docs.rs/plotters">
     <img style="display: inline!important" src="https://docs.rs/plotters/badge.svg"></img>
 </a>
-<a href="https://plumberserver.com/plotters-docs/plotters">
+<a href="https://plotters-rs.github.io/rustdoc/plotters/">
     <img style="display: inline! important" src="https://img.shields.io/badge/docs-development-lightgrey.svg"></img>
 </a>
 <a href="https://travis-ci.org/38/plotters">
@@ -172,6 +172,27 @@ including bitmap, vector graph, piston window and WebAssembly.
     </div>
 </div>
 
+<div class="galleryItem">
+    <a href="https://plotters-rs.github.io/plotters-doc-data/snowflake.png">
+        <img src="https://plotters-rs.github.io/plotters-doc-data/snowflake.png" class="galleryItem"></img>
+    </a>
+    <div class="galleryText">
+        Koch Snowflake
+        <a href="https://github.com/38/plotters/blob/master/examples/snowflake.rs">[code]</a>
+    </div>
+</div>
+
+
+<div class="galleryItem">
+    <a href="https://plotters-rs.github.io/plotters-doc-data/animation.png">
+        <img src="https://plotters-rs.github.io/plotters-doc-data/animation.gif" class="galleryItem"></img>
+    </a>
+    <div class="galleryText">
+        Koch Snowflake Animation
+        <a href="https://github.com/38/plotters/blob/master/examples/animation.rs">[code]</a>
+    </div>
+</div>
+
 
 ## Table of Contents
   * [Gallery](#gallery)
@@ -190,6 +211,7 @@ including bitmap, vector graph, piston window and WebAssembly.
   * [Misc](#misc)
     + [Development Version](#development-version)
     + [Reducing Depending Libraries && Turning Off Backends](#reducing-depending-libraries--turning-off-backends)
+    + [List of Features](#list-of-features)
   * [FAQ List](#faq-list)
 
 ## Quick Start
@@ -197,7 +219,7 @@ including bitmap, vector graph, piston window and WebAssembly.
 To use Plotters, you can simply add Plotters into your `Cargo.toml`
 ```toml
 [dependencies]
-plotters = "^0.2.6"
+plotters = "^0.2.7"
 ```
 
 And the following code draws a quadratic function. `src/main.rs`,
@@ -531,6 +553,35 @@ plotters = { git = "https://github.com/38/plotters.git", default_features = fals
 The library also allows consumers to make use of the [`Palette`](https://crates.io/crates/palette/) crate's color types by default.
 This behaviour can also be turned off by setting `default_features = false`.
 
+### List of Features
+
+This is the full list of features that is defined by `Plotters` crate. Use `default_features = false` to disable those default enabled features, and then you should be able to cherrypick what features you want to include into `Plotters` crate.
+
+| Name    |  Description | Addional Dependency |Default?|
+|---------|--------------|--------|------------|
+| bitmap  | Enable `BitMapBackend` Support| image | Yes |
+| svg     | Enable `SVGBackend` Support | svg | Yes |
+| datetime| Enable Date and Time Coordinate Support| chrono | Yes |
+| gif\_backend| Opt-in GIF animation Redendering support for `BitMapBackend`, implies `bitmap` enabled | gif | Yes |
+| piston | Enable `PistonWindowBackend` | piston\_window | No |
+| palette\_ext | Use crate `palette` for color expression| palette | Yes |
+| evcxr | Enable Evcxr support, which allows use `Plotters` in Jupyer Note Book | None | No |
+| make\_partial\_axis | Support for API `make_partial_axis`, which allows confguring partial axis from visible protion. | num-trait| Yes |
+
+## FAQ List
+
+* Why does the WASM example break on my machine ?
+
+    The WASM example requires using `wasm32` target to build. Using `cargo build` is likely to use the default target
+    which in most of the case is any of the x86 target. Thus you need add `--target=wasm32-unknown-unknown` in the cargo
+    parameter list  to build it.
+
+* How to draw text/circle/point/rectangle/... on the top of chart ?
+
+    As you may realized, Plotters is a drawing library rather than a traditional data plotting library,
+    you have the freedom to draw anything you want on the drawing area.
+    Use `DrawingArea::draw` to draw any element on the drawing area.
+
 
 <style>
     img {
@@ -551,13 +602,6 @@ This behaviour can also be turned off by setting `default_features = false`.
 </style>
 
 
-## FAQ List
-
-* Why does the WASM example work on my machine ?
-
-    The WASM example requires using `wasm32` target to build. Using `cargo build` is likely to use the default target
-    which in most of the case is any of the x86 target. Thus you need add `--target=wasm32-unknown-unknown` in the cargo
-    parameter list  to build it.
 */
 pub mod chart;
 pub mod coord;
@@ -586,7 +630,7 @@ pub mod prelude {
     };
 
     #[cfg(feature = "chrono")]
-    pub use crate::coord::{RangedDate, RangedDateTime};
+    pub use crate::coord::{RangedDate, RangedDateTime, RangedDuration};
 
     #[cfg(feature = "make_partial_axis")]
     pub use crate::coord::make_partial_axis;
